I2sRxDmaTransfer

Struct I2sRxDmaTransfer 

pub struct I2sRxDmaTransfer<'d, Dm, Buf>
where Dm: DriverMode, Buf: DmaRxBuffer,
{ /* private fields */ }
Available on crate feature unstable only.
A structure representing a DMA transfer.

This structure holds references to the driver instance, DMA buffers, and transfer status.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl<'d, Dm, Buf> I2sRxDmaTransfer<'d, Dm, Buf>
where Dm: DriverMode, Buf: DmaRxBuffer,

pub fn is_done(&self) -> bool

Returns true when Self::wait will not block.

pub fn wait(self) -> (Result<(), DmaError>, I2sRx<'d, Dm>, Buf::Final)

Waits for the transfer to finish and returns the peripheral and buffer.

pub fn stop(self) -> (I2sRx<'d, Dm>, Buf::Final)

Immediately stop the transfer and return the peripheral and buffer.

Source

impl<'d, Buf> I2sRxDmaTransfer<'d, Async, Buf>
where Buf: DmaRxBuffer,

pub async fn wait_async( self, ) -> (Result<(), DmaError>, I2sRx<'d, Async>, Buf::Final)

Waits for the transfer to finish and returns the peripheral and buffer.

pub async fn wait_for_done_async(&mut self) -> Result<(), DmaError>

Waits for the transfer to finish and returns the peripheral and buffer.

pub async fn wait_for_available_async(&mut self) -> Result<(), DmaError>

Waits for a condition that might indicate more data is available.